@@ -1,9 +1,12 @@
+"""A spectral density matrix can be decomposed into minimum phase functions. This is used in computing the
+pairwise spectral granger prediction."""
+
 import os
 from logging import getLogger
 
 import numpy as np
 
-if os.environ.get('SPECTRAL_CONNECTIVITY_ENABLE_GPU') == 'true':
+if os.environ.get("SPECTRAL_CONNECTIVITY_ENABLE_GPU") == "true":
     try:
         import cupy as xp
         from cupyx.scipy.fft import fft, ifft
@@ -19,12 +22,12 @@ logger = getLogger(__name__)
 
 
 def _conjugate_transpose(x):
-    '''Conjugate transpose of the last two dimensions of array x'''
+    """Conjugate transpose of the last two dimensions of array x"""
     return x.swapaxes(-1, -2).conjugate()
 
 
 def _get_intial_conditions(cross_spectral_matrix):
-    '''Returns a guess for the minimum phase factor using the Cholesky
+    """Returns a guess for the minimum phase factor using the Cholesky
     factorization.
 
     Parameters
@@ -37,31 +40,31 @@ def _get_intial_conditions(cross_spectral_matrix):
     -------
     minimum_phase_factor : array, shape (n_time_samples, ..., 1, n_signals,
                                          n_signals)
-    '''
+    """
     try:
         return xp.linalg.cholesky(
             ifft(cross_spectral_matrix, axis=-3)[..., 0:1, :, :].real
         ).swapaxes(-1, -2)
     except xp.linalg.linalg.LinAlgError:
         logger.warning(
-            'Computing the initial conditions using the Cholesky failed. '
-            'Using a random initial condition.')
+            "Computing the initial conditions using the Cholesky failed. "
+            "Using a random initial condition."
+        )
 
         new_shape = list(cross_spectral_matrix.shape)
         N_RAND = 1000
         new_shape[-3] = N_RAND
-        random_start = xp.random.standard_normal(
-            size=new_shape)
+        random_start = xp.random.standard_normal(size=new_shape)
 
-        random_start = xp.matmul(
-            random_start, _conjugate_transpose(random_start)).mean(
-                axis=-3, keepdims=True)
+        random_start = xp.matmul(random_start, _conjugate_transpose(random_start)).mean(
+            axis=-3, keepdims=True
+        )
 
         return xp.linalg.cholesky(random_start)
 
 
 def _get_causal_signal(linear_predictor):
-    '''Takes half the roots on the unit circle (zero lag) and all the roots
+    """Takes half the roots on the unit circle (zero lag) and all the roots
     inside the unit circle (positive lags).
 
     Gives you A_(t+1)(Z) / A_(t)(Z)
@@ -77,7 +80,7 @@ def _get_causal_signal(linear_predictor):
     causal_part_of_linear_predictor : array, shape (..., n_fft_samples,
                                                     n_signals, n_signals)
 
-    '''
+    """
     n_signals = linear_predictor.shape[-1]
     n_fft_samples = linear_predictor.shape[-3]
     linear_predictor_coefficients = ifft(linear_predictor, axis=-3)
@@ -88,15 +91,16 @@ def _get_causal_signal(linear_predictor):
     # Make the unit circle roots upper triangular
     lower_triangular_ind = np.tril_indices(n_signals, k=-1)
     linear_predictor_coefficients[
-        ..., 0, lower_triangular_ind[0], lower_triangular_ind[1]] = 0
+        ..., 0, lower_triangular_ind[0], lower_triangular_ind[1]
+    ] = 0
 
     # Take only the roots inside the unit circle (positive lags)
-    linear_predictor_coefficients[..., (n_fft_samples + 1) // 2:, :, :] = 0
+    linear_predictor_coefficients[..., (n_fft_samples + 1) // 2 :, :, :] = 0
     return fft(linear_predictor_coefficients, axis=-3)
 
 
-def _check_convergence(current, old, tolerance=1E-8):
-    '''Check convergence of Wilson algorithm at each time point.
+def _check_convergence(current, old, tolerance=1e-8):
+    """Check convergence of Wilson algorithm at each time point.
 
     Parameters
     ----------
@@ -113,15 +117,16 @@ def _check_convergence(current, old, tolerance=1E-8):
     is_converged : array, shape (n_time_points,)
         Boolean array that indicates whether the array has converged for
         each time point.
-    '''
+    """
     n_time_points = current.shape[0]
     error = xp.linalg.norm(
-        xp.reshape(current - old, (n_time_points, -1)), ord=xp.inf, axis=1)
+        xp.reshape(current - old, (n_time_points, -1)), ord=xp.inf, axis=1
+    )
     return error < tolerance
 
 
 def _get_linear_predictor(minimum_phase_factor, cross_spectral_matrix, I):
-    '''Measure how close the minimum phase factor is to the original
+    """Measure how close the minimum phase factor is to the original
     cross spectral matrix.
 
     Parameters
@@ -143,18 +148,20 @@ def _get_linear_predictor(minimum_phase_factor, cross_spectral_matrix, I):
                                      n_signals, n_signals)
         How much to adjust for the next guess for minimum phase factor.
 
-    '''
+    """
     covariance_sandwich_estimator = xp.linalg.solve(
-        minimum_phase_factor, cross_spectral_matrix)
+        minimum_phase_factor, cross_spectral_matrix
+    )
     covariance_sandwich_estimator = xp.linalg.solve(
-        minimum_phase_factor,
-        _conjugate_transpose(covariance_sandwich_estimator))
+        minimum_phase_factor, _conjugate_transpose(covariance_sandwich_estimator)
+    )
     return covariance_sandwich_estimator + I
 
 
-def minimum_phase_decomposition(cross_spectral_matrix, tolerance=1E-8,
-                                max_iterations=60):
-    '''Find a minimum phase matrix square root of the cross spectral
+def minimum_phase_decomposition(
+    cross_spectral_matrix, tolerance=1e-8, max_iterations=60
+):
+    """Find a minimum phase matrix square root of the cross spectral
     density using the Wilson algorithm.
 
     Parameters
@@ -175,34 +182,41 @@ def minimum_phase_decomposition(cross_spectral_matrix, tolerance=1E-8,
         The square root of the `cross_spectral_matrix` where all the poles
         are inside the unit circle (minimum phase).
 
-    '''
+    """
     n_time_points = cross_spectral_matrix.shape[0]
     n_signals = cross_spectral_matrix.shape[-1]
     I = xp.eye(n_signals)
     is_converged = xp.zeros(n_time_points, dtype=bool)
     minimum_phase_factor = xp.zeros(cross_spectral_matrix.shape)
-    minimum_phase_factor[..., :, :, :] = _get_intial_conditions(
-        cross_spectral_matrix)
+    minimum_phase_factor[..., :, :, :] = _get_intial_conditions(cross_spectral_matrix)
 
     for iteration in range(max_iterations):
         logger.debug(
-            'iteration: {0}, {1} of {2} converged'.format(
-                iteration, is_converged.sum(), len(is_converged)))
+            "iteration: {0}, {1} of {2} converged".format(
+                iteration, is_converged.sum(), len(is_converged)
+            )
+        )
         old_minimum_phase_factor = minimum_phase_factor.copy()
         linear_predictor = _get_linear_predictor(
-            minimum_phase_factor, cross_spectral_matrix, I)
+            minimum_phase_factor, cross_spectral_matrix, I
+        )
         minimum_phase_factor = xp.matmul(
-            minimum_phase_factor, _get_causal_signal(linear_predictor))
+            minimum_phase_factor, _get_causal_signal(linear_predictor)
+        )
 
         # If already converged at a time point, don't change.
         minimum_phase_factor[is_converged, ...] = old_minimum_phase_factor[
-            is_converged, ...]
+            is_converged, ...
+        ]
         is_converged = _check_convergence(
-            minimum_phase_factor, old_minimum_phase_factor, tolerance)
+            minimum_phase_factor, old_minimum_phase_factor, tolerance
+        )
         if xp.all(is_converged):
             return minimum_phase_factor
     else:
         logger.warning(
-            'Maximum iterations reached. {} of {} converged'.format(
-                is_converged.sum(), len(is_converged)))
+            "Maximum iterations reached. {} of {} converged".format(
+                is_converged.sum(), len(is_converged)
+            )
+        )
         return minimum_phase_factor
